
<!--
FrozenIsBool False
-->

#Inserter

##Doc
----


> 
> Inserter instances can insert a RowedVariablesList into a table
> checking maybe before if this line is new in the table or not
> depending on identifying items.
> 
> 

----

<small>
View the Inserter notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Inserter.ipynb)
</small>

